@@ -15,3 +15,11 @@ if HAS_SENTRY_DSN:
         request_bodies="always",
         environment=g.settings.stage,
     )
+
+from magicapi.Errors import BackendException
+
+
+class SentryBackendException(BackendException):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        capture_exception(self)
